_all_problem_names = []
_all_problems = []

def list_problem_names():
    """Returns a list of all Espresso problem names"""
    return _all_problem_names

def list_problems():
    """Returns a list of all Espresso problem classes"""
    return _all_problems


# from .example_name import ExampleName

# __all_problem_names__ = [ "ExampleName", ]
# __all_problems__ = [ ExampleName, ]

from ._xray_tomography import XrayTomography
from ._gravity_density import GravityDensity
from ._fmm_tomography import FmmTomography
from ._simple_regression import SimpleRegression

_all_problem_names = [
	'XrayTomography',
	'GravityDensity',
	'FmmTomography',
	'SimpleRegression',
]
_all_problems = [
	XrayTomography,
	GravityDensity,
	FmmTomography,
	SimpleRegression,
]


r"""Submodule for utility functions in cofi_espresso.

Some of these functions are used by contributors to conveniently implement their
problem class. Others can be utilised by users to perform analysis on inversion
results.

.. important::

    Please always use :func:`absolute_path` or :func:`loadtxt` when trying to load data
    from a relative path into an Espresso problem class.

"""

from .data_loader import loadtxt, absolute_path
from .file_handler import silent_remove

__all__ = [
    "loadtxt",
    "absolute_path",
    "silent_remove",
]
